import java.util.ArrayList;

/**
 * Repraesentiert eine Bank in der Banksimulation
 * @author Martin Ploetz
 *
 */
public class Bank {

	// Konstanten fr Name und BLZ
	final private String name;
	final private int blz;
	
	// Listen fr Kunden und Konten einer Bank
	private ArrayList<Kunde> kunden;
	private ArrayList<Konto> konten;
	
	/**
	 * Bank-Konstruktor
	 * @param name Name der Bank
	 * @param blz BLZ der Bank
	 */
	public Bank(String name, int blz){
		this.name = name;
		this.blz = blz;
		kunden = new ArrayList<Kunde>();
		konten = new ArrayList<Konto>();
	}

	public String getName() {
		return name;
	}

	public int getBlz() {
		return blz;
	}
	
	/**
	 * fuegt einen bereits bestehenden Kunden der Bank hinzu
	 * @param kunde
	 */
	public void addNewCustomer(Kunde kunde){
		kunden.add(kunde);
	}
	
	/**
	 * legt einen neuen Kunden an und fuegt diesen der Bank hinzu
	 * @param name Name des neuen Kunden
	 */
	public void addNewCustomer(String name){
		Kunde kunde = new Kunde(name);
		kunden.add(kunde);
	}
	
	/**
	 * fuegt ein bereits bestehendes Konto der Bank hinzu
	 * @param konto
	 */
	public void addNewAccount(Konto konto){
		konten.add(konto);
	}
	
	/**
	 * legt ein neues Konto an und fuegt es der Bank hinzu
	 * @param kontonr
	 * @param kunde
	 * @param bank
	 */
	public void addNewAccount(int kontonr, Kunde kunde, Bank bank){
		Konto konto = new Konto(kontonr, kunde, bank);
		konten.add(konto);
	}
	
	/**
	 * fuegt ein Konto einem Kunden hinzu
	 * @param konto
	 * @param kunde
	 */
	public void addAccountToCustomer(Konto konto, Kunde kunde){
		kunde.addAccount(konto);
	}
}
